@@ -1,4 +1,5 @@
-<?php $TRANSLATIONS = array(
+<?php
+$TRANSLATIONS = array(
 "Contacts" => "Контакты",
 "Save" => "Сохранить",
 "Cancel" => "Отмена",
@@ -12,3 +13,4 @@
 "Select groups" => "Выбрать группы",
 "Share" => "Сделать общим"
 );
+$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
