@@ -947,7 +947,7 @@
 						mime: mime,
 						etag: fileData.etag,
 						callback: function(url) {
-							iconDiv.css('background-image', 'url(' + url + ')');
+							iconDiv.css('background-image', 'url("' + url + '")');
 						}
 					});
 				}
@@ -959,7 +959,7 @@
 						};
 					var previewUrl = this.generatePreviewUrl(urlSpec);
 					previewUrl = previewUrl.replace('(', '%28').replace(')', '%29');
-					iconDiv.css('background-image', 'url(' + previewUrl + ')');
+					iconDiv.css('background-image', 'url("' + previewUrl + '")');
 				}
 			}
 			return tr;
