@@ -20,12 +20,15 @@ class Factory {
 
 	/**
 	 * get an L10N instance
+	 *
 	 * @param string $app
 	 * @param string|null $lang
 	 * @return \OC_L10N
 	 */
-	public function get($app) {
-		if (!isset($this->instances[$app])) {
+	public function get($app, $lang = null) {
+		if (!is_null($lang)) {
+			return new \OC_L10N($app, $lang);
+		} else if (!isset($this->instances[$app])) {
 			$this->instances[$app] = new \OC_L10N($app);
 		}
 		return $this->instances[$app];
